@@ -643,7 +643,10 @@ class QueuesV2QueueFunctionalTest(QueuesV1_1QueueFunctionalTest):
         expect_metadata = {'type': 'Bank Accounts', 'name': 'test1',
                            '_max_messages_post_size': 262144,
                            '_default_message_ttl': 3600,
-                           '_default_message_delay': 0}
+                           '_default_message_delay': 0,
+                           '_dead_letter_queue': None,
+                           '_dead_letter_queue_messages_ttl': None,
+                           '_max_claim_count': None}
         metadata = queue.metadata(force_reload=True)
         self.assertEqual(expect_metadata, metadata)
 
@@ -659,7 +662,10 @@ class QueuesV2QueueFunctionalTest(QueuesV1_1QueueFunctionalTest):
         expect_metadata = {'type': 'Bank Accounts', 'name': 'test1',
                            '_max_messages_post_size': 262144,
                            '_default_message_ttl': 3600,
-                           '_default_message_delay': 0}
+                           '_default_message_delay': 0,
+                           '_dead_letter_queue': None,
+                           '_dead_letter_queue_messages_ttl': None,
+                           '_max_claim_count': None}
         self.assertEqual(expect_metadata, metadata)
 
         # replace 'type', '_default_message_ttl' and add a new one 'age'
@@ -671,7 +677,10 @@ class QueuesV2QueueFunctionalTest(QueuesV1_1QueueFunctionalTest):
         expect_metadata = {'type': 'test', 'name': 'test1', 'age': 13,
                            '_max_messages_post_size': 262144,
                            '_default_message_ttl': 1000,
-                           '_default_message_delay': 0}
+                           '_default_message_delay': 0,
+                           '_dead_letter_queue': None,
+                           '_dead_letter_queue_messages_ttl': None,
+                           '_max_claim_count': None}
         self.assertEqual(expect_metadata, metadata)
 
         # replace 'name', remove 'type', '_default_message_ttl' and add a new
@@ -686,7 +695,10 @@ class QueuesV2QueueFunctionalTest(QueuesV1_1QueueFunctionalTest):
         expect_metadata = {'name': 'test2', 'age': 13, 'fake': 'test_fake',
                            '_max_messages_post_size': 262144,
                            '_default_message_ttl': 3600,
-                           '_default_message_delay': 0}
+                           '_default_message_delay': 0,
+                           '_dead_letter_queue': None,
+                           '_dead_letter_queue_messages_ttl': None,
+                           '_max_claim_count': None}
         self.assertEqual(expect_metadata, metadata)
 
         # replace 'name' to empty string and add a new empty dict 'empty_dict'.
@@ -701,6 +713,9 @@ class QueuesV2QueueFunctionalTest(QueuesV1_1QueueFunctionalTest):
         expect_metadata = {'name': '', 'age': 13, 'fake': 'test_fake',
                            '_max_messages_post_size': 262144,
                            '_default_message_delay': 0,
+                           '_dead_letter_queue': None,
+                           '_dead_letter_queue_messages_ttl': None,
+                           '_max_claim_count': None,
                            '_default_message_ttl': 3600, 'empty_dict': {}}
         self.assertEqual(expect_metadata, metadata)
 
@@ -711,5 +726,8 @@ class QueuesV2QueueFunctionalTest(QueuesV1_1QueueFunctionalTest):
         metadata = queue.metadata()
         expect_metadata = {'_max_messages_post_size': 262144,
                            '_default_message_ttl': 3600,
-                           '_default_message_delay': 0}
+                           '_default_message_delay': 0,
+                           '_dead_letter_queue': None,
+                           '_dead_letter_queue_messages_ttl': None,
+                           '_max_claim_count': None}
         self.assertEqual(expect_metadata, metadata)
